package com.example;

import javax.ws.rs.core.Response;

import org.apache.cxf.endpoint.Server;
import org.apache.cxf.jaxrs.client.JAXRSClientFactory;
import org.apache.cxf.jaxrs.client.WebClient;
import org.apache.cxf.jaxrs.spring.JAXRSServerFactoryBeanDefinitionParser.SpringJAXRSServerFactoryBean;
import org.apache.cxf.transport.local.LocalConduit;
import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(classes = { TestConfiguration.class })
public class AccountApiTest {
	
	private static Server server;
	private com.example.AccountApi api;
	
	@Autowired
	private SpringJAXRSServerFactoryBean serverFactory;

	@Before
	public void setup() throws Exception {
		server = serverFactory.create();
		api = JAXRSClientFactory.create(TestConfiguration.ENDPOINT_ADDRESS, com.example.AccountApi.class, TestConfiguration.defaultProviders());
		WebClient.getConfig(api).getRequestContext().put(LocalConduit.DIRECT_DISPATCH, Boolean.TRUE);
	}
	
	@After
	public void destroy() throws Exception {
		server.stop();
		server.destroy();
	}
	
	@Test
	public void addAccountParticipantsTest() {
		java.util.UUID accountId = null;

		Response response = this.api.addAccountParticipants(accountId);
		Assert.assertNotNull(response);
		com.example.model.AddAccountParticipants200Response result = response.readEntity(com.example.model.AddAccountParticipants200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void addParticipantsToGroupTest() {
		java.util.UUID groupId = null;
		java.util.UUID accountId = null;

		Response response = this.api.addParticipantsToGroup(groupId, accountId);
		Assert.assertNotNull(response);
	}

	@Test
	public void addUsersTest() {
		java.util.UUID accountId = null;

		Response response = this.api.addUsers(accountId);
		Assert.assertNotNull(response);
	}

	@Test
	public void createGroupTest() {
		java.util.UUID accountId = null;

		Response response = this.api.createGroup(accountId);
		Assert.assertNotNull(response);
		com.example.model.ParticipantGroup result = response.readEntity(com.example.model.ParticipantGroup.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void createSurveyTest() {
		java.util.UUID accountId = null;

		Response response = this.api.createSurvey(accountId);
		Assert.assertNotNull(response);
		com.example.model.SurveyDetails result = response.readEntity(com.example.model.SurveyDetails.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void deleteAccountParticipantsTest() {
		java.util.UUID accountId = null;

		Response response = this.api.deleteAccountParticipants(accountId);
		Assert.assertNotNull(response);
	}

	@Test
	public void deleteGroupTest() {
		java.util.UUID groupId = null;
		java.util.UUID accountId = null;

		Response response = this.api.deleteGroup(groupId, accountId);
		Assert.assertNotNull(response);
	}

	@Test
	public void deleteSurveyResultsTest() {
		java.util.UUID accountId = null;
		java.util.UUID surveyId = null;

		Response response = this.api.deleteSurveyResults(accountId, surveyId);
		Assert.assertNotNull(response);
	}

	@Test
	public void downloadAnonymisedSurveyReportTest() {
		java.util.UUID accountId = null;
		java.util.UUID surveyId = null;
		java.lang.String token = null;

		Response response = this.api.downloadAnonymisedSurveyReport(accountId, surveyId, token);
		Assert.assertNotNull(response);
	}

	@Test
	public void getAccountTest() {
		java.util.UUID accountId = null;

		Response response = this.api.getAccount(accountId);
		Assert.assertNotNull(response);
		com.example.model.AccountDetails result = response.readEntity(com.example.model.AccountDetails.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getAccountParticipantsTest() {
		java.util.UUID accountId = null;
		java.lang.String cursor = null;
		com.example.model.SortParticipants sort = null;

		Response response = this.api.getAccountParticipants(accountId, cursor, sort);
		Assert.assertNotNull(response);
		com.example.model.GetAccountParticipants200Response result = response.readEntity(com.example.model.GetAccountParticipants200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getGroupParticipantsTest() {
		java.util.UUID groupId = null;
		java.util.UUID accountId = null;
		java.lang.String cursor = null;
		com.example.model.SortParticipants sort = null;

		Response response = this.api.getGroupParticipants(groupId, accountId, cursor, sort);
		Assert.assertNotNull(response);
		com.example.model.GetGroupParticipants200Response result = response.readEntity(com.example.model.GetGroupParticipants200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getGroupsTest() {
		java.util.UUID accountId = null;

		Response response = this.api.getGroups(accountId);
		Assert.assertNotNull(response);
		java.util.List&lt;com.example.model.ParticipantGroup&gt; result = response.readEntity(java.util.List.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getReportsTest() {
		java.util.UUID accountId = null;
		java.lang.String cursor = null;
		com.example.model.SortSurveys sort = null;

		Response response = this.api.getReports(accountId, cursor, sort);
		Assert.assertNotNull(response);
		com.example.model.GetReports200Response result = response.readEntity(com.example.model.GetReports200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getSurveysTest() {
		java.util.UUID accountId = null;
		java.lang.String cursor = null;
		com.example.model.SortSurveys sort = null;
		java.util.List&lt;com.example.model.FilterSurveys&gt; filter = null;

		Response response = this.api.getSurveys(accountId, cursor, sort, filter);
		Assert.assertNotNull(response);
		com.example.model.GetSurveys200Response result = response.readEntity(com.example.model.GetSurveys200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getSurveyTemplatesTest() {
		java.util.UUID accountId = null;

		Response response = this.api.getSurveyTemplates(accountId);
		Assert.assertNotNull(response);
		java.util.List&lt;com.example.model.SurveyTemplate&gt; result = response.readEntity(java.util.List.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getTopicsTest() {
		java.util.UUID accountId = null;

		Response response = this.api.getTopics(accountId);
		Assert.assertNotNull(response);
		com.example.model.GetTopics200Response result = response.readEntity(com.example.model.GetTopics200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void getUsersTest() {
		java.util.UUID accountId = null;
		java.lang.String cursor = null;

		Response response = this.api.getUsers(accountId, cursor);
		Assert.assertNotNull(response);
		com.example.model.GetUsers200Response result = response.readEntity(com.example.model.GetUsers200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void patchAccountTest() {
		java.util.UUID accountId = null;

		Response response = this.api.patchAccount(accountId);
		Assert.assertNotNull(response);
		com.example.model.AccountDetails result = response.readEntity(com.example.model.AccountDetails.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void patchAccountParticipantTest() {
		java.util.UUID accountId = null;
		java.util.UUID participantId = null;

		Response response = this.api.patchAccountParticipant(accountId, participantId);
		Assert.assertNotNull(response);
		com.example.model.Participant result = response.readEntity(com.example.model.Participant.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void patchGroupTest() {
		java.util.UUID groupId = null;
		java.util.UUID accountId = null;

		Response response = this.api.patchGroup(groupId, accountId);
		Assert.assertNotNull(response);
		com.example.model.ParticipantGroup result = response.readEntity(com.example.model.ParticipantGroup.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void removeGroupParticipantsTest() {
		java.util.UUID groupId = null;
		java.util.UUID accountId = null;

		Response response = this.api.removeGroupParticipants(groupId, accountId);
		Assert.assertNotNull(response);
	}

	@Test
	public void removeUserTest() {
		java.util.UUID accountId = null;
		java.util.UUID userId = null;

		Response response = this.api.removeUser(accountId, userId);
		Assert.assertNotNull(response);
	}

	@Test
	public void requestAnonymisedSurveyReportDownloadTest() {
		java.util.UUID accountId = null;
		java.util.UUID surveyId = null;

		Response response = this.api.requestAnonymisedSurveyReportDownload(accountId, surveyId);
		Assert.assertNotNull(response);
		com.example.model.RequestAnonymisedSurveyReportDownload200Response result = response.readEntity(com.example.model.RequestAnonymisedSurveyReportDownload200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void searchParticipantsTest() {
		java.util.UUID accountId = null;
		java.lang.String query = null;
		java.lang.String cursor = null;
		com.example.model.SortParticipants sort = null;
		java.util.UUID group = null;

		Response response = this.api.searchParticipants(accountId, query, cursor, sort, group);
		Assert.assertNotNull(response);
		com.example.model.SearchParticipants200Response result = response.readEntity(com.example.model.SearchParticipants200Response.class);
		Assert.assertNotNull(result);
	}

	@Test
	public void updateUserTest() {
		java.util.UUID accountId = null;
		java.util.UUID userId = null;

		Response response = this.api.updateUser(accountId, userId);
		Assert.assertNotNull(response);
		com.example.model.UserDetails result = response.readEntity(com.example.model.UserDetails.class);
		Assert.assertNotNull(result);
	}

}
